@@ -7,25 +7,27 @@ ReadFirstPages <- function(doc, page.one = TRUE){
   # arXiv
   arXiv <- FALSE
   if (TRUE){
-    ind <- grep('arXiv:', doc)[1]
+    ind <- grep('arXiv:', doc, useBytes = TRUE)[1]
     if(!is.na(ind)){
       arXiv <- TRUE
       found.abstract <- TRUE  # assume no cover page for an arXiv paper
       arxinfo <- doc[ind]
       res$eprinttype <- 'arxiv'
       # need to check date since arXiv identifier format changed in Apr-07
-      m <- regexpr('[0-9]{1,2}[[:space:]][A-Z][a-z]{2}[[:space:]][0-9]{4}', arxinfo)
+      m <- regexpr('[0-9]{1,2}[[:space:]][A-Z][a-z]{2}[[:space:]][0-9]{4}', arxinfo,
+                   useBytes = TRUE)
 
       adate <- strptime(regmatches(arxinfo, m), format='%d %b %Y')
       if (length(adate)){
           res$date <- adate
           if (adate >= strptime('01 Apr 2007', format='%d %b %Y')){
-            m <- regexec('arXiv:([0-9]{4}[\\.][0-9]{4}v[0-9])[[:space:]]\\[([[:graph:]]+)\\]', arxinfo)
+              m <- regexec('arXiv:([0-9]{4}[\\.][0-9]{4}v[0-9])[[:space:]]\\[([[:graph:]]+)\\]',
+                           arxinfo, useBytes = TRUE)
             regm <- regmatches(arxinfo, m)
             res$eprintclass <- regm[[1]][3]
             res$eprint <- regm[[1]][2]
           }else{
-            m <- regexec('arXiv:([[:graph:]]+)\\s', arxinfo)
+            m <- regexec('arXiv:([[:graph:]]+)\\s', arxinfo, useBytes = TRUE)
             regm <- regmatches(arxinfo, m)
             res$eprint <- regm[[1]][2]
           }
@@ -36,23 +38,23 @@ ReadFirstPages <- function(doc, page.one = TRUE){
 
   if (TRUE){
     if (!arXiv){  # try to get url
-      ind <- grep('^[Uu]Rr][Ll]: ', doc)
+      ind <- grep('^[Uu]Rr][Ll]: ', doc, useBytes = TRUE)
       if (length(ind))
-        res$url <- gsub('^[Uu]Rr][Ll]: ', '', doc[ind])
+        res$url <- gsub('^[Uu]Rr][Ll]: ', '', doc[ind], useBytes = TRUE)
 
 
       # volume
-      m <- regexec('(Vol|Volume)[[:punct:]]?[[:space:]]?([0-9]+)', doc)
+      m <- regexec('(Vol|Volume)[[:punct:]]?[[:space:]]?([0-9]+)', doc, useBytes = TRUE)
       if (length(m[[1]]) != 1)
         res$volume <- unlist(regmatches(doc, m))[3]
 
       # number
-      m <- regexec('([Nn]o\\.|Number|Issue)[[:space:]]([0-9]{1,3})', doc)
+      m <- regexec('([Nn]o\\.|Number|Issue)[[:space:]]([0-9]{1,3})', doc, useBytes = TRUE)
       if (length(m[[1]]) != 1)
         res$number <- unlist(regmatches(doc, m))[3]
       # pages -pdftotext has trouble with "-"
       m <- regexec('([0-9]{1,4}) ?[-\u1390\u2212\ufe58\ufe63\uff0d\u2012-\u2015] ?([0-9]{1,4})[[:punct:]]?$',
-                   doc)
+                   doc, useBytes = TRUE)
       tmatch <- unlist(regmatches(doc, m))
       if (length(tmatch))
         res$pages <- paste0(tmatch[-1], collapse='-')
@@ -63,32 +65,38 @@ ReadFirstPages <- function(doc, page.one = TRUE){
                            doc[1], useBytes = TRUE)  # [[:upper:]][[:alpha:]]+
       if (length(journ.ind[[1]]) != 1){
         temp <- regmatches(doc[1], journ.ind)[[1]]
-        res$journal <- gsub(' $', '', temp[2])
+        res$journal <- gsub(' $', '', temp[2], useBytes = TRUE)
         res$year <- temp[3]
         doc <- doc[-1L]
       }
 
       # year
       if (is.null(res$year)){
-        m <- regexpr('\\<(19|20)[0-9]{2}\\>', doc)
+        m <- regexpr('\\<(19|20)[0-9]{2}\\>', doc, useBytes = TRUE)
         if (any(m != -1L))
           res$year <- regmatches(doc, m)[1L]
       }
     }
 
     # keywords
-    ind <- grep('Key ?words( and phrases)?(:|.)[[:space:]]?', doc, ignore.case = TRUE)
+    ind <- grep('Key ?words( and phrases)?(:|.)[[:space:]]?', doc, ignore.case = TRUE,
+                useBytes = TRUE)
     if (length(ind)){
-      res$keywords <- sub('Key ?words( and phrases)?(:|.)[[:space:]]?', '', doc[ind], ignore.case = TRUE)
-      if (ind+1 <= length(doc) && length(grep('^([[:alpha:]]+[,;]? ?)+\\.?$', doc[ind+1])))
+        res$keywords <- sub('Key ?words( and phrases)?(:|.)[[:space:]]?', '', doc[ind],
+                            ignore.case = TRUE, useBytes = TRUE)
+        if (ind+1 <= length(doc) && grepl('^([[:alpha:]]+[,;]? ?)+\\.?$', doc[ind+1],
+                    useBytes = TRUE))
           res$keywords <- paste(res$keywords, doc[ind+1])
-      if (ind+2 <= length(doc) && length(grep('^([[:alpha:]]+[,;]? ?)+\\.?$', doc[ind+2])))
+        if (ind+2 <= length(doc) && grepl('^([[:alpha:]]+[,;]? ?)+\\.?$', doc[ind+2],
+                    useBytes = TRUE))
           res$keywords <- paste(res$keywords, doc[ind+2])
-      res$keywords <- gsub(';', ',', res$keywords)  # keywords need to be comma separated for BibLaTeX
-      res$keywords <- gsub('[;,]$', '', res$keywords)
-      doc <- doc[1L:(ind-1)]  # shorten doc used to search for author and title
+        ## keywords need to be comma separated for BibLaTeX
+        res$keywords <- gsub(';', ',', res$keywords, useBytes = TRUE)
+        res$keywords <- gsub('[;,]$', '', res$keywords, useBytes = TRUE)
+        doc <- doc[1L:(ind-1)]  # shorten doc used to search for author and title
         found.abstract <- TRUE
-    }else if(length(abst.ind <- grep('^[1I]\\.?[[:blank:]]Introduction([[:space:]]|$)', doc))){
+    }else if(length(abst.ind <- grep('^[1I]\\.?[[:blank:]]Introduction([[:space:]]|$)', doc,
+                                     useBytes = TRUE))){
       if (abst.ind > 2L){
         doc <- doc[1L:(abst.ind - 1L)]
         if (page.one)  # allows for first section at top of 2nd page
@@ -111,21 +119,22 @@ ReadFirstPages <- function(doc, page.one = TRUE){
 
 #' @keywords internal
 CheckJSTOR <- function(doc1, doc2, file){
-  ind <- grep('http://www\\.jstor\\.org/stable/([0-9]+)', doc1)[1]
+  ind <- grep('http://www\\.jstor\\.org/stable/([0-9]+)', doc1, useBytes = TRUE)[1]
   if (!is.na(ind)){
     res <- try(GetJSTOR(doc1), TRUE)
     if (inherits(res, 'try-catch'))
       return(NA)
-    res$eprint <- gsub('[^0-9]+', '', doc1[ind])
+    res$eprint <- gsub('[^0-9]+', '', doc1[ind], useBytes = TRUE)
     res$eprinttype = 'jstor'
     res$url <- paste0('http://www.jstor.org/stable/', res$eprint)
     res$file <- normalizePath(file)
 
-  }else if (length(ind <- grep('http://links.jstor.org/sici', doc1))){  # old format for JSTOR papers
+  }else if (length(ind <- grep('http://links.jstor.org/sici', doc1, useBytes = TRUE))){
+    ## old format for JSTOR papers
     res <- try(GetJSTOR(doc1), TRUE)
     if (inherits(res, 'try-catch'))
       return(NA)
-    res$url <- sub('Stable URL:[[:space:]]', '', doc1[ind])
+    res$url <- sub('Stable URL:[[:space:]]', '', doc1[ind], useBytes = TRUE)
   }else{
     return(NA)
   }
@@ -141,19 +150,23 @@ CheckJSTOR <- function(doc1, doc2, file){
 
   ##########################################
   # try for keywords and DOI on page 2
-  ind <- grep('Key ?words( and phrases)?:[[:space:]]?', doc2, ignore.case = TRUE)
+  ind <- grep('Key ?words( and phrases)?:[[:space:]]?', doc2, ignore.case = TRUE, useBytes = TRUE)
 
   if (length(ind)){
-    res$keywords <- sub('[[:space:]]*Key ?words( and phrases)?:[[:space:]]?', '', doc2[ind], ignore.case = TRUE)
-    if (ind+1 <= length(doc2) && length(grep('^([[:alpha:]]+[ ,;]?)+\\.?$', doc2[ind+1])))
+      res$keywords <- sub('[[:space:]]*Key ?words( and phrases)?:[[:space:]]?', '', doc2[ind],
+                          ignore.case = TRUE, useBytes = TRUE)
+      if (ind+1 <= length(doc2) && grepl('^([[:alpha:]]+[ ,;]?)+\\.?$', doc2[ind+1],
+                  useBytes = TRUE))
         res$keywords <- paste(res$keywords, doc2[ind+1])
-    if (ind+2 <= length(doc2) && length(grep('^([[:alpha:]]+[ ,;]?)+\\.?$', doc2[ind+2])))
+      if (ind+2 <= length(doc2) && grepl('^([[:alpha:]]+[ ,;]?)+\\.?$', doc2[ind+2],
+                  useBytes = TRUE))
         res$keywords <- paste(res$keywords, doc2[ind+2])
-    res$keywords <- gsub(';', ',', res$keywords)  # keywords need to be comma separated for BibLaTeX
+      ## keywords need to be comma separated for BibLaTeX
+      res$keywords <- gsub(';', ',', res$keywords, useBytes = TRUE)
   }
 
   pattern  <- "\\b(10[.][0-9]{4,}(?:[.][0-9]+)*/(?:(?![\"&\'])\\S)+)\\b"
-  m <- regexpr(pattern, doc2, perl=TRUE)
+  m <- regexpr(pattern, doc2, perl=TRUE, useBytes = TRUE)
   if (any(m != -1))
     res$doi <- unlist(regmatches(doc2, m))
 
@@ -162,38 +175,39 @@ CheckJSTOR <- function(doc1, doc2, file){
 
 #' @keywords internal
 GetJSTOR <- function(doc){  # take extra caution for long title, author list, or journal info
-  aut.ind <- grep('Author\\(s\\): ', doc)
+  aut.ind <- grep('Author\\(s\\): ', doc, useBytes = TRUE)
   if (!length(aut.ind)){  # old format for JSTOR papers.
-    url.ind <- grep('Stable URL', doc)
-    source.ind <- grep('([[:print:]]+),[[:space:]]Vol\\. ', doc)
+    url.ind <- grep('Stable URL', doc, useBytes = TRUE)
+    source.ind <- grep('([[:print:]]+),[[:space:]]Vol\\. ', doc, useBytes = TRUE)
 
     # immediately above source.ind is author, if line above that has a semicolon, it is also author info
-    aut.ind <- grep(';', doc[1:(source.ind-1)])
+    aut.ind <- grep(';', doc[1:(source.ind-1)], useBytes = TRUE)
     if(!is.na(aut.ind)){
       author <- paste0(doc[aut.ind:(source.ind-1)], collapse = ' ')
     }else{
       aut.ind <- source.ind-1
       author <- doc[aut.ind]
     }
-    author <- gsub(';', ',', author)
+    author <- gsub(';', ',', author, useBytes = TRUE)
     author <- as.person(author)
 
-    publisher.ind <- grep('published by', doc)[1]
-    m <- regexec('published by ([[:alpha:], -]+).?$', doc[publisher.ind])
+    publisher.ind <- grep('published by', doc, useBytes = TRUE)[1]
+    m <- regexec('published by ([[:alpha:], -]+).?$', doc[publisher.ind], useBytes = TRUE)
     publisher <- regmatches(doc[publisher.ind], m)[[1]][2]
 
     jinfo <- paste0(doc[source.ind:(url.ind-1)], collapse = ' ')
   }else{
-    reviewed.ind <- grep('Reviewed work\\(s\\):', doc)
+    reviewed.ind <- grep('Reviewed work\\(s\\):', doc, useBytes = TRUE)
     if (length(reviewed.ind))
       doc <- doc[-reviewed.ind]
 
-    publisher.ind <- grep('Published by: ', doc)
-    url.ind <- grep('Stable URL: ', doc)
-    publisher <- sub('Published by: ', '', paste0(doc[publisher.ind:(url.ind-1)], collapse = ' '))
-    source.ind <- grep('Source: ', doc)
+    publisher.ind <- grep('Published by: ', doc, useBytes = TRUE)
+    url.ind <- grep('Stable URL: ', doc, useBytes = TRUE)
+    publisher <- sub('Published by: ', '',
+                     paste0(doc[publisher.ind:(url.ind-1)], collapse = ' '), useBytes = TRUE)
+    source.ind <- grep('Source: ', doc, useBytes = TRUE)
     author <- paste0(doc[aut.ind:(source.ind-1)], collapse = ' ')
-    author <- sub('Author\\(s\\): ', '', author)
+    author <- sub('Author\\(s\\): ', '', author, useBytes = TRUE)
     author <- as.person(author)
 
     jinfo <- paste0(doc[source.ind:(publisher.ind-1)], collapse = ' ')
@@ -206,7 +220,7 @@ GetJSTOR <- function(doc){  # take extra caution for long title, author list, or
 
   pattern <- paste0('^(Source:[[:space:]])?([[:print:]]+),[[:space:]]Vol\\. ([0-9]+)(, No\\. ([[:digit:]/]+))?\\.? ',
     '\\(([[:upper:]][[:lower:]]{2}\\.?, )?([0-9]{4})\\), pp. ([[:digit:] -]+)')
-  m <- regexec(pattern, jinfo)
+  m <- regexec(pattern, jinfo, useBytes = TRUE)
   journal.info <- unlist(regmatches(jinfo, m))
   if (!length(journal.info))  # Source: line has unexpected format
     return(list(title = title, author = author, publisher = publisher))
@@ -217,9 +231,10 @@ GetJSTOR <- function(doc){  # take extra caution for long title, author list, or
     number <- NULL  # some journals have no number/issue
 
   year <- journal.info[8]  # journal.info[length(journal.info)-1]
-  pages <- gsub(' ', '', journal.info[9])  # gsub for edge case # gsub('pp. ', '', journal.info[length(journal.info)])
+  ## gsub for edge case # gsub('pp. ', '', journal.info[length(journal.info)])
+  pages <- gsub(' ', '', journal.info[9], useBytes = TRUE)
   ## poppler doesn't read the JSTOR en-dash always
-  if(!length(grep('-', pages))){
+  if(!grepl('-', pages, useBytes = TRUE)){
     psplit <- floor(nchar(pages)/2)
     pages <- paste0(substr(pages, 1, psplit), '-', substr(pages, psplit+1, nchar(pages)))
   }
@@ -231,7 +246,7 @@ GetJSTOR <- function(doc){  # take extra caution for long title, author list, or
 #' @keywords internal
 GetAuthorTitle <- function(doc, found.abstract, kw){
   if (!identical(found.abstract, TRUE)){
-    abst.ind <- grep('^A[Bb][Ss][Tt][Rr][Aa][Cc][Tt]|^S[Uu][Mm][Mm][Aa][Rr][Yy]|^S[Yy][Nn][Oo][Pp][Ss][Ii][Ss][:.]?\\>', doc)
+    abst.ind <- grep('^A[Bb][Ss][Tt][Rr][Aa][Cc][Tt]|^S[Uu][Mm][Mm][Aa][Rr][Yy]|^S[Yy][Nn][Oo][Pp][Ss][Ii][Ss][:.]?\\>', doc, useBytes = TRUE)
     if (length(abst.ind) && abst.ind > 2L){  # assume title/author comes before Abstract. need 2nd cond. for ind==1
       doc <- doc[1L:(abst.ind - 1L)]
       found.abstract <- TRUE
@@ -251,24 +266,28 @@ GetAuthorTitle <- function(doc, found.abstract, kw){
     "(,? Jr| II| III| IV)?(,? MD.?)?(,? P(h|H)D.?)?",  # optional qualifications
     #  "(?<!", BAD.WORDS, ")",
     "(,.|;.)*( and| &)?[[:space:]]?)+$"),             # and, ",", ";", or "&" to seperate names. Repeat
-    doc[-1], perl=FALSE)              # first line can't have authors
+    doc[-1], perl=FALSE, useBytes = TRUE) # first line can't have authors
   aut.match <- regmatches(doc[-1], aut.ind)
   if (length(aut.match) == 0){
     aut.match <- NULL
   }else{
-    aut.match <- gsub("(,? MD)?(,? P(H|h)D)?", '', aut.match)  # remove MD and PhD
-    aut.match <- gsub("[^[:alpha:] ,'-]", '', aut.match)  # remove punct at end of last name
+      ## remove MD and PhD
+      aut.match <- gsub("(,? MD)?(,? P(H|h)D)?", '', aut.match, useBytes = TRUE)
+      ## remove punct at end of last name
+      aut.match <- gsub("[^[:alpha:] ,'-]", '', aut.match, useBytes = TRUE)
     # aut.match <- gsub("^A[Uu][Tt][Hh][Oo][Rr]( |: )|^B[Yy]( |: )", '', aut.match)  # remove author or by at start
-    aut.match <- gsub("^((B[Yy]|A[Uu][Tt][Hh][Oo][Rr][Ss]?|and):?[[:space:]])?", '', aut.match)  # remove author or by at start
-    aut.match <- gsub("\\<AND\\>", "and", aut.match)
+      aut.match <- gsub("^((B[Yy]|A[Uu][Tt][Hh][Oo][Rr][Ss]?|and):?[[:space:]])?", '',
+                        aut.match, useBytes = TRUE)  # remove author or by at start
+    aut.match <- gsub("\\<AND\\>", "and", aut.match, useBytes = TRUE)
     # remove bad words. can't get negative look-ahead working :(
-    temp <- grep(BAD.WORDS, aut.match, ignore.case = TRUE)
+    temp <- grep(BAD.WORDS, aut.match, ignore.case = TRUE, useBytes = TRUE)
     if (length(temp)){
       aut.ind[which(aut.ind > 0L)[temp]] <- -1L
       aut.match <- aut.match[-temp]
     }
     if (!is.null(kw)){  # extra protection from including title with author
-      temp <- grep(paste0(unlist(strsplit(kw, ',? ')), collapse = '|'), aut.match, ignore.case = TRUE)
+        temp <- grep(paste0(unlist(strsplit(kw, ',? ')), collapse = '|'), aut.match,
+                     ignore.case = TRUE, useBytes = TRUE)
       if (length(temp)){
         aut.ind[which(aut.ind > 0L)[temp]] <- -1L
         aut.match <- aut.match[-temp]
@@ -299,13 +318,13 @@ GetAuthorTitle <- function(doc, found.abstract, kw){
   first.match <- FALSE
   done.match <- FALSE
   while (i <= N && !done.match){
-    temp <- grep(BAD.WORDS, doc[i], ignore.case = TRUE)
+    temp <- grep(BAD.WORDS, doc[i], ignore.case = TRUE, useBytes = TRUE)
     title.ind <- regexpr(paste0(  # "(?!", BAD.WORDS, ")",
                                 "^[\u201c\u022]?[[:upper:]][[:alpha:]'\u201c\u201d\u022-]+[ -]",
                                 #"([[:alpha:]:,' ]){2,}(\\.|!|\\?)?$"),
                                 "([[:alpha:]:,' \u201c\u201d\u022-]+){2,}.?$"),
                                 #"(?<!", BAD.WORDS, ")"),
-                         doc[i], perl = TRUE)
+                         doc[i], perl = TRUE, useBytes = TRUE)
     if (title.ind != -1 && !length(temp)){
       if (!first.match){
         first.match <- TRUE
@@ -325,15 +344,17 @@ GetAuthorTitle <- function(doc, found.abstract, kw){
   }else{
     if (length(match.ind)){  # undo reversing of doc when author matched
       if (i > 3L){
-        if (length(grep("[[:alpha:]', -]+", doc[i-3L])))
+        if (grepl("[[:alpha:]', -]+", doc[i-3L], useBytes = TRUE))
           title.match <- c(doc[i-3L], title.match)
       }
       title.match <- rev(title.match)
     }
     title.match <- paste0(title.match, collapse = ' ')
     # simple fix for case troubles
-    title.match <- gsub("([[:alpha:]])([[:alpha:]'-]*)", "\\U\\1\\L\\2", title.match, perl=TRUE)
-    title.match <- gsub('[^\\w]*$', '', title.match, perl = TRUE)  # remove superscripted char indicating footnote for title
+    title.match <- gsub("([[:alpha:]])([[:alpha:]'-]*)", "\\U\\1\\L\\2", title.match,
+                        perl = TRUE, useBytes = TRUE)
+    ## remove superscripted char indicating footnote for title
+    title.match <- gsub('[^\\w]*$', '', title.match, perl = TRUE, useBytes = TRUE)
   }
 
   #return(list(ind=which(aut.ind != -1L), match=aut.match, ab.ind=ind, title.match))
@@ -390,7 +411,7 @@ CleanAuthorTitle <- function(bib1, bib2, bibMeta, file){
 #' @keywords internal
 SearchDOIText <- function(txt){
   pattern  <- "\\b(10[.][0-9]{4,}(?:[.][0-9]+)*/(?:(?![\"&\'])\\S)+)\\b"
-  m <- regexpr(pattern, txt, perl=TRUE)
+  m <- regexpr(pattern, txt, perl = TRUE, useBytes = TRUE)
   if(all(m == -1)){
     return(NA)
   }else{
@@ -409,30 +430,28 @@ ProcessPDFMeta <- function(x, enc = 'UTF-8'){
   found.tags <- substring(x, 1L, 16L)
   ind <- pmatch(tags, found.tags)
   if (!is.na(ind[1])){
-    title.info <- sub(re, "", x[ind[1]])
-    t.check <- grep('[[:upper:]][[:lower:]-]* [[:alpha:]]+', title.info)
-    if (length(t.check))
+    title.info <- sub(re, "", x[ind[1]], useBytes = TRUE)
+    if (grepl('[[:upper:]][[:lower:]-]* [[:alpha:]]+', title.info, useBytes = TRUE))
       res$title <- title.info
   }
 
   if (!is.na(ind[2])){
-    aut.info <- sub(re, "", x[ind[2]])
-    a.check <- grep("\\w[\\.'-]? \\w", aut.info)
-    if (length(a.check))
+    aut.info <- sub(re, "", x[ind[2]], useBytes = TRUE)
+    if (grepl("\\w[\\.'-]? \\w", aut.info, useBytes = TRUE))
       res$author <- aut.info
   }
 
   # add keywords if available
   ind <- pmatch('Keywords', found.tags)
   if(!is.na(ind)){
-    res$keywords <- sub('Keywords:[[:space:]]+', '', x[ind])
+    res$keywords <- sub('Keywords:[[:space:]]+', '', x[ind], useBytes = TRUE)
     if (res$keywords =='')
       res$keywords <- NULL
   }
 
   ind <- pmatch('Subject:', found.tags)
   if (!is.na(ind)){
-    subj <- sub('Subject:[[:space:]]+', '', x[ind])
+    subj <- sub('Subject:[[:space:]]+', '', x[ind], useBytes = TRUE)
 
     if (subj != ''){
       res <- c(res, ProcessPDFSubject(subj))
@@ -444,7 +463,7 @@ ProcessPDFMeta <- function(x, enc = 'UTF-8'){
   if (is.null(res$year)){
     ind <- pmatch('ModDate', found.tags)
     if(!is.na(ind)){
-      date <- sub('ModDate:[[:space:]]+', '', x[ind])
+      date <- sub('ModDate:[[:space:]]+', '', x[ind], useBytes = TRUE)
       date <- suppressWarnings(lubridate::parse_date_time(date,
                                              orders = c("%m/%d/%y %H:%M:%S", "%m/%d %H:%M:%S %y")))
       if (!is.na(date)){
@@ -452,7 +471,7 @@ ProcessPDFMeta <- function(x, enc = 'UTF-8'){
         res$date <- trunc(date, 'days')
       }
     }else if (!is.na(ind <-pmatch('CreationDate', found.tags))){
-      date <- sub('CreationDate:[[:space:]]+', '', x[ind])
+      date <- sub('CreationDate:[[:space:]]+', '', x[ind], useBytes = TRUE)
       date <- suppressWarnings(lubridate::parse_date_time(date,
                                      orders = c("%m/%d/%y %H:%M:%S", "%m/%d %H:%M:%S %y")))
       if (!is.na(date)){
@@ -471,7 +490,8 @@ ProcessPDFMeta <- function(x, enc = 'UTF-8'){
 ProcessPDFSubject <- function(subj){
   res <- list()
 
-  journ.ind <- regexec('^([[:upper:]][[:alpha:] ]+)[,\\.;]?[[:print:]]*\\(?\\<(19|20)[0-9]{2}\\>', subj)
+  journ.ind <- regexec('^([[:upper:]][[:alpha:] ]+)[,\\.;]?[[:print:]]*\\(?\\<(19|20)[0-9]{2}\\>',
+                       subj, useBytes = TRUE)
   temp <- unlist(regmatches(subj, journ.ind))
   if (length(temp)){
     res$journal <- temp[2]
@@ -479,16 +499,16 @@ ProcessPDFSubject <- function(subj){
       res$year <- temp[3]
   }
 
-  m <- regexec('[Vv]ol(\\.|ume)?[[:space:]]([0-9]{1,3})', subj)
+  m <- regexec('[Vv]ol(\\.|ume)?[[:space:]]([0-9]{1,3})', subj, useBytes = TRUE)
   if (length(m[[1]]) != 1)
     res$volume <- unlist(regmatches(subj, m))[3]
 
-  m <- regexec('([Nn]o\\.|Number|Issue)[[:space:]]([0-9]{1,3})', subj)
+  m <- regexec('([Nn]o\\.|Number|Issue)[[:space:]]([0-9]{1,3})', subj, useBytes = TRUE)
   if (length(m[[1]]) != 1)
     res$number <- unlist(regmatches(subj, m))[3]
 
   if (is.null(res$volume) && is.null(res$number)){
-    m <- regexec('\\(([0-9]{1,3})\\)[[:blank:]]?([0-9]{1,3})', subj)[[1]]
+    m <- regexec('\\(([0-9]{1,3})\\)[[:blank:]]?([0-9]{1,3})', subj, useBytes = TRUE)[[1]]
     if (length(m[[1]]) != 1){
       temp <- regmatches(subj, m)[[1]]
       res$volume <- temp[2]
@@ -497,9 +517,10 @@ ProcessPDFSubject <- function(subj){
   }
 
   # be extra careful matching hypen. usuallly it's \u2013, an en dash
-  m <- regexpr('[0-9]+[-\u2212\ufe58\ufe63\uff0d\u2012-\u2015][0-9]+', subj)
+  m <- regexpr('[0-9]+[-\u2212\ufe58\ufe63\uff0d\u2012-\u2015][0-9]+', subj, useBytes = TRUE)
   if (m != -1){
-    res$pages <- grep('[0-9]+[-\u2212\ufe58\ufe63\uff0d\u2012-\u2015][0-9]+', subj, value=TRUE)
+      res$pages <- grep('[0-9]+[-\u2212\ufe58\ufe63\uff0d\u2012-\u2015][0-9]+', subj,
+                        value = TRUE, useBytes = TRUE)
   }
   return(res)
 }
